==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrPublishHrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ CsrPublishHrefHints.JSON_PROPERTY_ALLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class CsrPublishHrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        POST(String.valueOf("POST")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public CsrPublishHrefHints() {
    }

    public CsrPublishHrefHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public CsrPublishHrefHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrPublishHrefHints csrPublishHrefHints = (CsrPublishHrefHints) o;
        return Objects.equals(this.allow, csrPublishHrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrPublishHrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CsrPublishHrefHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Describes allowed HTTP verbs for the &#x60;href&#x60;
 */
@ApiModel(description = "Describes allowed HTTP verbs for the `href`")
@JsonPropertyOrder({ CsrPublishHrefHints.JSON_PROPERTY_ALLOW })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CsrPublishHrefHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        POST(String.valueOf("POST")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public CsrPublishHrefHints() {
    }

    public CsrPublishHrefHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public CsrPublishHrefHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CsrPublishHrefHints csrPublishHrefHints = (CsrPublishHrefHints) o;
        return Objects.equals(this.allow, csrPublishHrefHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CsrPublishHrefHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
